@@ -3,21 +3,18 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
+ * The contents of this file constitute Original Code as defined in and
+ * are subject to the Apple Public Source License Version 1.2 (the
+ * "License").  You may not use this file except in compliance with the
+ * License.  Please obtain a copy of the License at
+ * http://www.apple.com/publicsource and read it before using this file.
  * 
- * This file contains Original Code and/or Modifications of Original Code
- * as defined in and that are subject to the Apple Public Source License
- * Version 2.0 (the 'License'). You may not use this file except in
- * compliance with the License. Please obtain a copy of the License at
- * http://www.opensource.apple.com/apsl/ and read it before using this
- * file.
- * 
- * The Original Code and all software distributed under the License are
- * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This Original Code and all software distributed under the License are
+ * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
- * Please see the License for the specific language governing rights and
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.  
+ * Please see the License for the specific language governing rights and 
  * limitations under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
@@ -40,7 +37,7 @@
 class AppleUSBHubPort;
 class AppleUSBHub;
 
-typedef IOReturn (AppleUSBHubPort::*ChangeHandlerFuncPtr)(UInt16 changeFlags, UInt16 statusFlags);
+typedef IOReturn (AppleUSBHubPort::*ChangeHandlerFuncPtr)(UInt16 changeFlags);
 
 typedef struct {
     ChangeHandlerFuncPtr handler;
@@ -123,20 +120,20 @@ public:
     virtual void 		stop(void);
 
     IOReturn 		AddDevice(void);
-    void 		RemoveDevice(void);
+    void 		RemoveDevice();
     IOReturn		ResetPort();
     bool 		StatusChanged(void);
 
     void 		InitPortVectors(void);
     void 		SetPortVector(ChangeHandlerFuncPtr routine, UInt32 condition);
-    IOReturn 		DefaultOverCrntChangeHandler(UInt16 changeFlags, UInt16 statusFlags);
-    IOReturn 		DefaultResetChangeHandler(UInt16 changeFlags, UInt16 statusFlags);
-    IOReturn 		DefaultSuspendChangeHandler(UInt16 changeFlags, UInt16 statusFlags);
-    IOReturn 		DefaultEnableChangeHandler(UInt16 changeFlags, UInt16 statusFlags);
-    IOReturn 		DefaultConnectionChangeHandler(UInt16 changeFlags, UInt16 statusFlags);
-    IOReturn 		AddDeviceResetChangeHandler(UInt16 changeFlags, UInt16 statusFlags);
-    IOReturn 		HandleResetPortHandler(UInt16 changeFlags, UInt16 statusFlags);
-    IOReturn 		HandleSuspendPortHandler(UInt16 changeFlags, UInt16 statusFlags);
+    IOReturn 		DefaultOverCrntChangeHandler(UInt16 changeFlags);
+    IOReturn 		DefaultResetChangeHandler(UInt16 changeFlags);
+    IOReturn 		DefaultSuspendChangeHandler(UInt16 changeFlags);
+    IOReturn 		DefaultEnableChangeHandler(UInt16 changeFlags);
+    IOReturn 		DefaultConnectionChangeHandler(UInt16 changeFlags);
+    IOReturn 		AddDeviceResetChangeHandler(UInt16 changeFlags);
+    IOReturn 		HandleResetPortHandler(UInt16 changeFlags);
+    IOReturn 		HandleSuspendPortHandler(UInt16 changeFlags);
     void 		FatalError(IOReturn err, char *str);
 
     AppleUSBHub *	GetHub(void) { return _hub; }
